Functions
=========

.. currentmodule:: crema

Primary Functions
*****************
.. autofunction:: assign_confidence

Parsers
*****************
.. autofunction:: read_tide
.. autofunction:: read_msamanda
.. autofunction:: read_msfragger
.. autofunction:: read_msgf
.. autofunction:: read_pepxml
.. autofunction:: read_mztab
.. autofunction:: read_txt

Writers
*****************
.. autofunction:: to_txt
